pub struct CommonCliOptions {
pub wallet_state_path: Option<PathBuf>,
pub keystore_path: Option<PathBuf>,
pub with_wallet: Option<String>,
pub storage_config: Option<String>,
pub common_storage_options: CommonStorageOptions,
pub wasm_runtime: Option<WasmRuntime>,
pub application_logs: bool,
pub tokio_threads: Option<usize>,
pub tokio_blocking_threads: Option<usize>,
}Expand description
Wallet, keystore, and storage configuration options common to all Linera client tools.
Fields
wallet_state_path: Option<PathBuf>Sets the file storing the private state of user chains (an empty one will be created if missing).
keystore_path: Option<PathBuf>Sets the file storing the keystore state.
with_wallet: Option<String>Given an ASCII alphanumeric parameter X, read the wallet state and the wallet
storage config from the environment variables LINERA_WALLET_{X} and
LINERA_STORAGE_{X} instead of LINERA_WALLET and
LINERA_STORAGE.
storage_config: Option<String>Storage configuration for the blockchain history.
common_storage_options: CommonStorageOptionsCommon storage options.
wasm_runtime: Option<WasmRuntime>The WebAssembly runtime to use.
application_logs: boolOutput log messages from contract execution.
tokio_threads: Option<usize>The number of Tokio worker threads to use.
tokio_blocking_threads: Option<usize>The number of Tokio blocking threads to use.
Implementations
Sourceimpl CommonCliOptions
impl CommonCliOptions
pub fn suffix(&self) -> String
pub fn storage_config(&self) -> Result<StorageConfig, Error>
pub fn wallet_path(&self) -> Result<PathBuf, Error>
pub fn keystore_path(&self) -> Result<PathBuf, Error>
pub fn wallet(&self) -> Result<Wallet, Error>
pub fn keystore(&self) -> Result<Keystore, Error>
pub fn create_wallet( &self, genesis_config: GenesisConfig, ) -> Result<Wallet, Error>
pub fn create_keystore( &self, testing_prng_seed: Option<u64>, ) -> Result<Keystore, Error>